==> coola-0.2.1-py3-none-any.whl: coola/comparators/numpy_.py <==
from __future__ import annotations

__all__ = [
    "ArrayAllCloseOperator",
    "ArrayEqualityOperator",
    "get_mapping_allclose",
    "get_mapping_equality",
]

import logging
from typing import TYPE_CHECKING, Any
from unittest.mock import Mock

from coola.comparators.base import BaseAllCloseOperator, BaseEqualityOperator
from coola.utils.imports import check_numpy, is_numpy_available

if TYPE_CHECKING:
    from coola.testers import BaseAllCloseTester, BaseEqualityTester

if is_numpy_available():
    import numpy as np
else:  # pragma: no cover
    np = Mock()

logger = logging.getLogger(__name__)


class ArrayAllCloseOperator(BaseAllCloseOperator[np.ndarray]):
    r"""Implements an allclose operator for ``numpy.ndarray``.

    Args:
        check_dtype (bool, optional): If ``True``, the data type of
            the arrays are checked, otherwise the data types are
            ignored. Default: ``True``

    Example usage:

    ```pycon
    >>> import numpy as np
    >>> from coola.comparators import ArrayAllCloseOperator
    >>> from coola.testers import AllCloseTester
    >>> tester = AllCloseTester()
    >>> op = ArrayAllCloseOperator()
    >>> op.allclose(tester, np.arange(21), np.arange(21))
    True

    ```
    """

    def __init__(self, check_dtype: bool = True) -> None:
        check_numpy()
        self._check_dtype = bool(check_dtype)

    def __eq__(self, other: Any) -> bool:
        if not isinstance(other, self.__class__):
            return False
        return self._check_dtype == other._check_dtype

    def __repr__(self) -> str:
        return f"{self.__class__.__qualname__}(check_dtype={self._check_dtype})"

    def allclose(
        self,
        tester: BaseAllCloseTester,
        object1: np.ndarray,
        object2: Any,
        rtol: float = 1e-5,
        atol: float = 1e-8,
        equal_nan: bool = False,
        show_difference: bool = False,
    ) -> bool:
        if object1 is object2:
            return True
        if not isinstance(object2, np.ndarray):
            if show_difference:
                logger.info(f"object2 is not a numpy.ndarray: {type(object2)}")
            return False
        if self._check_dtype and object1.dtype != object2.dtype:
            if show_difference:
                logger.info(
                    f"numpy.ndarray data types are different: {object1.shape} vs {object2.shape}"
                )
            return False
        if object1.shape != object2.shape:
            if show_difference:
                logger.info(
                    f"numpy.ndarray shapes are different: {object1.shape} vs {object2.shape}"
                )
            return False
        object_equal = np.allclose(object1, object2, rtol=rtol, atol=atol, equal_nan=equal_nan)
        if show_difference and not object_equal:
            logger.info(f"numpy.ndarrays are different\nobject1=\n{object1}\nobject2=\n{object2}")
        return object_equal

    def clone(self) -> ArrayAllCloseOperator:
        return self.__class__(check_dtype=self._check_dtype)


class ArrayEqualityOperator(BaseEqualityOperator[np.ndarray]):
    r"""Implements an equality operator for ``numpy.ndarray``.

    Args:
        check_dtype (bool, optional): If ``True``, the data type of
            the arrays are checked, otherwise the data types are
            ignored. Default: ``True``

    Example usage:

    ```pycon
    >>> import numpy as np
    >>> from coola.comparators import ArrayEqualityOperator
    >>> from coola.testers import EqualityTester
    >>> tester = EqualityTester()
    >>> op = ArrayEqualityOperator()
    >>> op.equal(tester, np.arange(21), np.arange(21))
    True

    ```
    """

    def __init__(self, check_dtype: bool = True) -> None:
        check_numpy()
        self._check_dtype = bool(check_dtype)

    def __eq__(self, other: Any) -> bool:
        if not isinstance(other, self.__class__):
            return False
        return self._check_dtype == other._check_dtype

    def __repr__(self) -> str:
        return f"{self.__class__.__qualname__}(check_dtype={self._check_dtype})"

    def clone(self) -> ArrayEqualityOperator:
        return self.__class__(check_dtype=self._check_dtype)

    def equal(
        self,
        tester: BaseEqualityTester,
        object1: np.ndarray,
        object2: Any,
        show_difference: bool = False,
    ) -> bool:
        if object1 is object2:
            return True
        if not isinstance(object2, np.ndarray):
            if show_difference:
                logger.info(f"object2 is not a numpy.ndarray: {type(object2)}")
            return False
        if self._check_dtype and object1.dtype != object2.dtype:
            if show_difference:
                logger.info(
                    f"numpy.ndarray data types are different: {object1.shape} vs {object2.shape}"
                )
            return False
        if object1.shape != object2.shape:
            if show_difference:
                logger.info(
                    f"numpy.ndarray shapes are different: {object1.shape} vs {object2.shape}"
                )
            return False
        object_equal = np.array_equal(object1, object2)
        if show_difference and not object_equal:
            logger.info(f"numpy.ndarrays are different\nobject1=\n{object1}\nobject2=\n{object2}")
        return object_equal


def get_mapping_allclose() -> dict[type[object], BaseAllCloseOperator]:
    r"""Gets a default mapping between the types and the allclose
    operators.

    This function returns an empty dictionary if numpy is not
    installed.

    Returns:
        dict: The mapping between the types and the allclose
            operators.

    Example usage:

    ```pycon
    >>> from coola.comparators.numpy_ import get_mapping_allclose
    >>> get_mapping_allclose()
    {<class 'numpy.ndarray'>: ArrayAllCloseOperator(check_dtype=True)}

    ```
    """
    if not is_numpy_available():
        return {}
    return {np.ndarray: ArrayAllCloseOperator()}


def get_mapping_equality() -> dict[type[object], BaseEqualityOperator]:
    r"""Gets a default mapping between the types and the equality
    operators.

    This function returns an empty dictionary if numpy is not
    installed.

    Returns:
        dict: The mapping between the types and the equality
            operators.

    Example usage:

    ```pycon
    >>> from coola.comparators.numpy_ import get_mapping_equality
    >>> get_mapping_equality()
    {<class 'numpy.ndarray'>: ArrayEqualityOperator(check_dtype=True)}

    ```
    """
    if not is_numpy_available():
        return {}
    return {np.ndarray: ArrayEqualityOperator()}

==> coola-0.2.2-py3-none-any.whl: coola/comparators/numpy_.py <==
r"""Implement some equality operators for ``numpy.ndarray``.

The operators are registered only if ``numpy`` is available.
"""

from __future__ import annotations

__all__ = [
    "ArrayAllCloseOperator",
    "ArrayEqualityOperator",
    "get_mapping_allclose",
    "get_mapping_equality",
]

import logging
from typing import TYPE_CHECKING, Any
from unittest.mock import Mock

from coola.comparators.base import BaseAllCloseOperator, BaseEqualityOperator
from coola.utils.imports import check_numpy, is_numpy_available

if TYPE_CHECKING:
    from coola.testers import BaseAllCloseTester, BaseEqualityTester

if is_numpy_available():
    import numpy as np
else:  # pragma: no cover
    np = Mock()

logger = logging.getLogger(__name__)


class ArrayAllCloseOperator(BaseAllCloseOperator[np.ndarray]):
    r"""Implement an allclose operator for ``numpy.ndarray``.

    Args:
        check_dtype (bool, optional): If ``True``, the data type of
            the arrays are checked, otherwise the data types are
            ignored.

    Example usage:

    ```pycon
    >>> import numpy as np
    >>> from coola.comparators import ArrayAllCloseOperator
    >>> from coola.testers import AllCloseTester
    >>> tester = AllCloseTester()
    >>> op = ArrayAllCloseOperator()
    >>> op.allclose(tester, np.arange(21), np.arange(21))
    True

    ```
    """

    def __init__(self, check_dtype: bool = True) -> None:
        check_numpy()
        self._check_dtype = bool(check_dtype)

    def __eq__(self, other: object) -> bool:
        if not isinstance(other, self.__class__):
            return False
        return self._check_dtype == other._check_dtype

    def __repr__(self) -> str:
        return f"{self.__class__.__qualname__}(check_dtype={self._check_dtype})"

    def allclose(
        self,
        tester: BaseAllCloseTester,
        object1: np.ndarray,
        object2: Any,
        rtol: float = 1e-5,
        atol: float = 1e-8,
        equal_nan: bool = False,
        show_difference: bool = False,
    ) -> bool:
        if object1 is object2:
            return True
        if not isinstance(object2, np.ndarray):
            if show_difference:
                logger.info(f"object2 is not a numpy.ndarray: {type(object2)}")
            return False
        if self._check_dtype and object1.dtype != object2.dtype:
            if show_difference:
                logger.info(
                    f"numpy.ndarray data types are different: {object1.shape} vs {object2.shape}"
                )
            return False
        if object1.shape != object2.shape:
            if show_difference:
                logger.info(
                    f"numpy.ndarray shapes are different: {object1.shape} vs {object2.shape}"
                )
            return False
        object_equal = np.allclose(object1, object2, rtol=rtol, atol=atol, equal_nan=equal_nan)
        if show_difference and not object_equal:
            logger.info(f"numpy.ndarrays are different\nobject1=\n{object1}\nobject2=\n{object2}")
        return object_equal

    def clone(self) -> ArrayAllCloseOperator:
        return self.__class__(check_dtype=self._check_dtype)


class ArrayEqualityOperator(BaseEqualityOperator[np.ndarray]):
    r"""Implement an equality operator for ``numpy.ndarray``.

    Args:
        check_dtype (bool, optional): If ``True``, the data type of
            the arrays are checked, otherwise the data types are
            ignored.

    Example usage:

    ```pycon
    >>> import numpy as np
    >>> from coola.comparators import ArrayEqualityOperator
    >>> from coola.testers import EqualityTester
    >>> tester = EqualityTester()
    >>> op = ArrayEqualityOperator()
    >>> op.equal(tester, np.arange(21), np.arange(21))
    True

    ```
    """

    def __init__(self, check_dtype: bool = True) -> None:
        check_numpy()
        self._check_dtype = bool(check_dtype)

    def __eq__(self, other: object) -> bool:
        if not isinstance(other, self.__class__):
            return False
        return self._check_dtype == other._check_dtype

    def __repr__(self) -> str:
        return f"{self.__class__.__qualname__}(check_dtype={self._check_dtype})"

    def clone(self) -> ArrayEqualityOperator:
        return self.__class__(check_dtype=self._check_dtype)

    def equal(
        self,
        tester: BaseEqualityTester,
        object1: np.ndarray,
        object2: Any,
        show_difference: bool = False,
    ) -> bool:
        if object1 is object2:
            return True
        if not isinstance(object2, np.ndarray):
            if show_difference:
                logger.info(f"object2 is not a numpy.ndarray: {type(object2)}")
            return False
        if self._check_dtype and object1.dtype != object2.dtype:
            if show_difference:
                logger.info(
                    f"numpy.ndarray data types are different: {object1.shape} vs {object2.shape}"
                )
            return False
        if object1.shape != object2.shape:
            if show_difference:
                logger.info(
                    f"numpy.ndarray shapes are different: {object1.shape} vs {object2.shape}"
                )
            return False
        object_equal = np.array_equal(object1, object2)
        if show_difference and not object_equal:
            logger.info(f"numpy.ndarrays are different\nobject1=\n{object1}\nobject2=\n{object2}")
        return object_equal


def get_mapping_allclose() -> dict[type[object], BaseAllCloseOperator]:
    r"""Get a default mapping between the types and the allclose
    operators.

    This function returns an empty dictionary if numpy is not
    installed.

    Returns:
        The mapping between the types and the allclose operators.

    Example usage:

    ```pycon
    >>> from coola.comparators.numpy_ import get_mapping_allclose
    >>> get_mapping_allclose()
    {<class 'numpy.ndarray'>: ArrayAllCloseOperator(check_dtype=True)}

    ```
    """
    if not is_numpy_available():
        return {}
    return {np.ndarray: ArrayAllCloseOperator()}


def get_mapping_equality() -> dict[type[object], BaseEqualityOperator]:
    r"""Get a default mapping between the types and the equality
    operators.

    This function returns an empty dictionary if numpy is not
    installed.

    Returns:
        The mapping between the types and the equality operators.

    Example usage:

    ```pycon
    >>> from coola.comparators.numpy_ import get_mapping_equality
    >>> get_mapping_equality()
    {<class 'numpy.ndarray'>: ArrayEqualityOperator(check_dtype=True)}

    ```
    """
    if not is_numpy_available():
        return {}
    return {np.ndarray: ArrayEqualityOperator()}
